==> tikiwiki-2.2.tgz: tikiwiki/lib/setup/menus.php <==
<?php

// $Id: menus.php 14007 2008-08-01 19:47:56Z marclaporte $
// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for
// details.

//this script may only be included - so its better to die if called directly.
$access->check_script($_SERVER["SCRIPT_NAME"],basename(__FILE__));

// Application menu
//TODO: remove from here : this is only used for mod-application_menu and tiki-map

function setDisplayMenu($name) {
	global $smarty;
	if ( getCookie($name, 'menu', isset($_COOKIE['menu']) ? null : 'o') == 'o' ) {
		$smarty->assign('mnu_'.$name, 'display:block;');
		$smarty->assign('icn_'.$name, 'o');
	} else $smarty->assign('mnu_'.$name, 'display:none;');
}

setDisplayMenu('nlmenu');
setDisplayMenu('evmenu');
setDisplayMenu('chartmenu');
setDisplayMenu('mymenu');
setDisplayMenu('wfmenu');
setDisplayMenu('usrmenu');
setDisplayMenu('friendsmenu');
setDisplayMenu('wikimenu');
setDisplayMenu('homeworkmenu');
setDisplayMenu('srvmenu');
setDisplayMenu('trkmenu');
setDisplayMenu('quizmenu');
setDisplayMenu('formenu');
setDisplayMenu('dirmenu');
setDisplayMenu('admmnu');
setDisplayMenu('faqsmenu');
setDisplayMenu('galmenu');
setDisplayMenu('cmsmenu');
setDisplayMenu('blogmenu');
setDisplayMenu('filegalmenu');
setDisplayMenu('mapsmenu');
setDisplayMenu('layermenu');
setDisplayMenu('shtmenu');
setDisplayMenu('prjmenu');

==> tikiwiki-4.2p4.tgz: tikiwiki/lib/setup/menus.php <==
<?php

// $Id: menus.php 19965 2009-07-06 21:31:46Z alain_desilets $
// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for
// details.

//this script may only be included - so its better to die if called directly.
$access->check_script($_SERVER["SCRIPT_NAME"],basename(__FILE__));

// Application menu
//TODO: remove from here : this is only used for mod-application_menu and tiki-map

function setDisplayMenu($name) {
	global $smarty;
	if ( getCookie($name, 'menu', isset($_COOKIE['menu']) ? null : 'o') == 'o' ) {
		$smarty->assign('mnu_'.$name, 'display:block;');
		$smarty->assign('icn_'.$name, 'o');
	} else {
		$smarty->assign('mnu_'.$name, 'display:none;');
	}
}

setDisplayMenu('nlmenu');
setDisplayMenu('evmenu');
setDisplayMenu('chartmenu');
setDisplayMenu('mymenu');
setDisplayMenu('wfmenu');
setDisplayMenu('usrmenu');
setDisplayMenu('friendsmenu');
setDisplayMenu('wikimenu');
setDisplayMenu('homeworkmenu');
setDisplayMenu('srvmenu');
setDisplayMenu('trkmenu');
setDisplayMenu('quizmenu');
setDisplayMenu('formenu');
setDisplayMenu('dirmenu');
setDisplayMenu('admmnu');
setDisplayMenu('faqsmenu');
setDisplayMenu('galmenu');
setDisplayMenu('cmsmenu');
setDisplayMenu('blogmenu');
setDisplayMenu('filegalmenu');
setDisplayMenu('mapsmenu');
setDisplayMenu('layermenu');
setDisplayMenu('shtmenu');
setDisplayMenu('prjmenu');
